@@ -1,4 +1,16 @@
-
+#' @title Set configuration parameters
+#' @name .conf_set_options
+#' @noRd
+#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#'
+#' @param processing_bloat       Estimated growth size of R memory relative
+#'                               to block size.
+#' @param rstac_pagination_limit Limit of number of items returned by STAC.
+#' @param gdal_creation_options  GDAL creation options for GeoTiff.
+#' @param gdalcubes_chunk_size   Chunk size to be used by gdalcubes
+#' @param sources                Data sources
+#' @param colors                 Color values
+#' @param ...                    Other configuration params
 .conf_set_options <- function(processing_bloat = NULL,
                               rstac_pagination_limit = NULL,
                               gdal_creation_options = NULL,
@@ -16,8 +28,9 @@
     # process processing_bloat
     if (!is.null(processing_bloat)) {
         .check_num(processing_bloat,
-                   min = 1, len_min = 1, len_max = 1,
-                   msg = "invalid 'processing_bloat' parameter"
+            min = 1, len_min = 1, len_max = 1, max = 10,
+            is_integer = TRUE,
+            msg = "invalid 'processing_bloat' parameter"
         )
         sits_env$config[["processing_bloat"]] <- processing_bloat
     }
@@ -25,8 +38,9 @@
     # process rstac_pagination_limit
     if (!is.null(rstac_pagination_limit)) {
         .check_num(rstac_pagination_limit,
-                   min = 1, len_min = 1, len_max = 1,
-                   msg = "invalid 'rstac_pagination_limit' parameter"
+            min = 1, len_min = 1, len_max = 1, max = 500,
+            is_integer = TRUE,
+            msg = "invalid 'rstac_pagination_limit' parameter"
         )
         sits_env$config[["rstac_pagination_limit"]] <- rstac_pagination_limit
     }
@@ -34,19 +48,19 @@
     # process gdal_creation_options
     if (!is.null(gdal_creation_options)) {
         .check_chr(gdal_creation_options,
-                   allow_empty = FALSE,
-                   regex = "^.+=.+$",
-                   msg = "invalid 'gdal_creation_options' parameter"
+            allow_empty = FALSE,
+            regex = "^.+=.+$",
+            msg = "invalid 'gdal_creation_options' parameter"
         )
         sits_env$config[["gdal_creation_options"]] <- gdal_creation_options
     }
     # process gdalcubes_chunk_size
     if (!is.null(gdalcubes_chunk_size)) {
         .check_num(gdalcubes_chunk_size,
-                   min_len = 3,
-                   max_len = 3,
-                   is_named = FALSE,
-                   msg = "invalid gdalcubes chunk size"
+            min_len = 3,
+            max_len = 3,
+            is_named = FALSE,
+            msg = "invalid gdalcubes chunk size"
         )
         sits_env$config[["gdalcubes_chunk_size"]] <- gdalcubes_chunk_size
     }
@@ -58,17 +72,16 @@
         names(sources) <- toupper(names(sources))
 
         sources <- lapply(sources, function(source) {
-
             # pre-condition
             .check_lst(source,
-                       min_len = 2,
-                       msg = "invalid 'source' parameter"
+                min_len = 2,
+                msg = "invalid 'source' parameter"
             )
 
             # check that source contains essential parameters
             .check_chr_contains(names(source),
-                                contains = c("s3_class", "collections"),
-                                msg = "invalid 'source' parameter"
+                contains = c("s3_class", "collections"),
+                msg = "invalid 'source' parameter"
             )
             names(source) <- tolower(names(source))
 
@@ -125,9 +138,7 @@
 #' @noRd
 #' @return default configuration file
 #'
-#'
 .conf_file <- function() {
-
     # load the default configuration file
     yml_file <- system.file("extdata", "config.yml", package = "sits")
 
@@ -143,7 +154,6 @@
 #' @noRd
 #' @return default internal configuration file
 .conf_internals_file <- function() {
-
     # load the default configuration file
     yml_file <- system.file("extdata", "config_internals.yml", package = "sits")
 
@@ -158,7 +168,6 @@
 #' @noRd
 #' @return default color configuration file
 .conf_colors_file <- function() {
-
     # load the default configuration file
     yml_file <- system.file("extdata", "config_colors.yml", package = "sits")
 
@@ -180,24 +189,30 @@
         input = color_yml_file,
         merge.precedence = "override"
     )
-    config_colors <- config_colors$colors
-    base_names <- names(config_colors)
-    color_table <- purrr::map2_dfr(config_colors, base_names, function(cl, bn) {
-        cc_tb <- tibble::tibble(name = names(cl),
-                                color = unlist(cl),
-                                group = bn)
+    class_schemes <- config_colors$class_schemes
+    sits_env[["config"]] <- utils::modifyList(sits_env[["config"]],
+                                              class_schemes,
+                                              keep.null = FALSE
+    )
+    colors <- config_colors$colors
+    color_table <- purrr::map2_dfr(colors, names(colors),
+                                   function(cl, nm) {
+        cc_tb <- tibble::tibble(
+            name = nm,
+            color = cl
+        )
         return(cc_tb)
     })
     # set the color table
     .conf_set_color_table(color_table)
-    return(invisible(NULL))
+    return(invisible(color_table))
 }
 #' @title Set user color table
 #' @name .conf_set_color_table
 #' @description Loads a user color table
 #' @keywords internal
 #' @noRd
-#' @return NULL, called for side effects
+#' @return Called for side effects
 .conf_set_color_table <- function(color_tb) {
     # pre condition - table contains name and hex code
     .check_chr_contains(
@@ -209,9 +224,10 @@
     # pre condition - table contains no duplicates
     tbd <- dplyr::distinct(color_tb, .data[["name"]])
     .check_that(nrow(tbd) == nrow(color_tb),
-                msg = "color table contains duplicate names")
+        msg = "color table contains duplicate names"
+    )
     sits_env$color_table <- color_tb
-    return(invisible(NULL))
+    return(invisible(color_tb))
 }
 #' @title Merge user colors with default colors
 #' @name .conf_merge_colors
@@ -228,78 +244,136 @@
         name <- names_user_colors[[i]]
         col <- col_user_colors[[i]]
         id <- which(color_table$name == name)
-        if (length(id) > 0)
+        if (length(id) > 0) {
             color_table[id, "color"] <- col
-        else
+        } else {
             color_table <- tibble::add_row(color_table,
-                                           name = name,
-                                           color = col,
-                                           group = "User")
+                name = name,
+                color = col
+            )
+        }
     }
     .conf_set_color_table(color_table)
-    return(invisible(NULL))
+    return(invisible(color_table))
 }
+#' @title Return the default color table
+#' @name .conf_colors
+#' @keywords internal
+#' @noRd
+#' @return default color table
+#'
 .conf_colors <- function() {
     return(sits_env$color_table)
 }
-#' @title Return the user configuration file
-#' @name .conf_user_file
+#' @title Configure fonts to be used
+#' @name .conf_set_fonts
 #' @keywords internal
 #' @noRd
-#' @return user configuration file
-.conf_user_file <- function() {
+#' @return NULL, called for side effects
+#'
+.conf_set_fonts <- function() {
+    # verifies if sysfonts package is installed
+    .check_require_packages("sysfonts")
+    .check_require_packages("showtext")
+    showtext::showtext_auto()
+    sysfonts::font_add_google("IBM Plex Sans", family = "plex_sans")
+    sysfonts::font_add_google("Roboto", family = "roboto")
+    sysfonts::font_add_google("Lato", family = "lato")
 
-    # load the default configuration file
+    return(NULL)
+}
+#' @title Return the user configuration set in enviromental variable
+#' @name .conf_user_env_var
+#' @keywords internal
+#' @noRd
+#' @return YAML user configuration
+.conf_user_env_var <- function() {
+    # load the default user configuration file
     yml_file <- Sys.getenv("SITS_CONFIG_USER_FILE")
-    # check if the file exists
+    yaml_user_config <- NULL
+    # check if the file exists when env var is set
     if (nchar(yml_file) > 0) {
         .check_warn(
             .check_file(yml_file,
-                        msg = paste(
-                            "invalid configuration file informed in",
-                            "SITS_CONFIG_USER_FILE"
-                        )
+                msg = paste(
+                    "invalid configuration file informed in",
+                    "SITS_CONFIG_USER_FILE"
+                )
             )
         )
-    }
-
-    return(yml_file)
-}
-
-.conf_set_user_file <- function() {
-    # try to find a valid user configuration file
-    user_yml_file <- .conf_user_file()
-
-    if (file.exists(user_yml_file)) {
-        config <- yaml::yaml.load_file(
-            input = user_yml_file,
-            merge.precedence = "override"
+        # if the YAML file exists, try to load it
+        tryCatch({
+            yaml_user_config <- yaml::yaml.load_file(
+                    input = yml_file,
+                    merge.precedence = "override"
+            )},
+            error = function(e) {
+                warning(msg = paste(
+                    "invalid configuration file informed in",
+                    "SITS_CONFIG_USER_FILE"), call. = TRUE)
+            }
         )
-        if (!purrr::is_null(config$colors)) {
-            user_colors <- config$colors
+    }
+    # returns the user configuration, otherwise null
+    return(yaml_user_config)
+}
+#' @title Load the user configuration file
+#' @name .conf_set_user_file
+#' @param config_user_file  Configuration file provided by user
+#' @keywords internal
+#' @noRd
+#' @return user configuration file
+.conf_set_user_file <- function(config_user_file = NULL) {
+    # try to find a valid user configuration file
+    # check config user file is valid
+    if (!purrr::is_null(config_user_file) && !is.na(config_user_file)) {
+        user_config <- tryCatch(
+            yaml::yaml.load_file(config_user_file, error.label = "",
+                                 readLines.warn = FALSE),
+            error = function(e) {
+                stop("invalid user configuration file", call. = TRUE)
+            }
+        )
+    } else {
+        user_config <- .conf_user_env_var()
+    }
+    if (!purrr::is_null(user_config)) {
+        if (!purrr::is_null(user_config$colors)) {
+            user_colors <- user_config$colors
             .conf_merge_colors(user_colors)
-            config$colors <- NULL
+            user_config$colors <- NULL
         }
-        if (length(config) > 0) {
-            config <- utils::modifyList(sits_env[["config"]],
-                                        config,
-                                        keep.null = FALSE
+        if (!purrr::is_null(user_config$class_schemes)) {
+            class_schemes <- user_config$class_schemes
+            sits_env[["config"]] <- utils::modifyList(
+                sits_env[["config"]],
+                class_schemes,
+                keep.null = FALSE
+            )
+            user_config$class_schemes <- NULL
+        }
+        if (length(user_config) > 0) {
+            user_config <- utils::modifyList(sits_env[["config"]],
+                user_config,
+                keep.null = FALSE
             )
             # set options defined by user (via YAML file)
             # modifying existing configuration
             .conf_set_options(
-                processing_bloat = config[["processing_bloat"]],
-                rstac_pagination_limit = config[["rstac_pagination_limit"]],
-                gdal_creation_options = config[["gdal_creation_options"]],
-                gdalcubes_chunk_size = config[["gdalcubes_chunk_size"]],
-                sources = config[["sources"]],
-                colors = config[["colors"]]
+                processing_bloat = user_config[["processing_bloat"]],
+                rstac_pagination_limit =
+                    user_config[["rstac_pagination_limit"]],
+                gdal_creation_options =
+                    user_config[["gdal_creation_options"]],
+                gdalcubes_chunk_size =
+                    user_config[["gdalcubes_chunk_size"]],
+                sources = user_config[["sources"]],
+                colors = user_config[["colors"]],
+                tmap   = user_config[["tmap"]]
             )
         }
-
     }
 }
-
 #' @title Check band availability
 #' @name .conf_check_bands
 #' @description Checks if the requested bands are available in the collection
@@ -312,7 +386,6 @@
 #'
 #' @return              Called for side effects.
 .conf_check_bands <- function(source, collection, bands) {
-
     # set caller to show in errors
     .check_set_caller(".conf_check_bands")
 
@@ -324,7 +397,6 @@
         source = source,
         collection = collection
     )
-
     .check_chr_within(
         x = bands,
         within = c(sits_bands, source_bands),
@@ -333,46 +405,7 @@
             "the provided bands."
         )
     )
-
-    # remove bands with equal names, like NDVI, EVI...
-    source_bands <- source_bands[!source_bands %in% sits_bands]
-
-    return(invisible(NULL))
-}
-#' @title Check metatype associated to the data
-#' @name .conf_data_meta_type
-#' @keywords internal
-#' @noRd
-#' @description associates a valid SITS class to the data
-#'
-#' @param  data    Time series or data cube.
-#'
-#' @return         The meta data type associated to a sits object.
-.conf_data_meta_type <- function(data) {
-
-    # set caller to show in errors
-    .check_set_caller(".conf_data_meta_type")
-
-    # if the data is one of the classes recognized by sits
-    if (inherits(data, .conf("sits_s3_classes"))) {
-        return(data)
-    } else if (inherits(data, "tbl_df")) {
-        # is this a data cube or a sits tibble?
-        if (all(.conf("sits_cube_cols")
-                %in% colnames(data))) {
-            class(data) <- c("raster_cube", class(data))
-
-            return(data)
-        } else if (all(.conf("sits_tibble_cols") %in% colnames(data))) {
-            class(data) <- c("sits", class(data))
-            return(data)
-        }
-    }
-
-    .check_that(FALSE,
-                local_msg = "Data not recognized as a sits object",
-                msg = "invalid 'data' parameter"
-    )
+    return(invisible(bands))
 }
 #' @title Get names associated to a configuration key
 #' @name .conf_names
@@ -389,15 +422,14 @@
             return(NULL)
         }
     )
-
     # post-condition
     .check_chr(res,
-               allow_empty = FALSE,
-               msg = paste(
-                   "invalid names for",
-                   paste0("'", paste0(key, collapse = "$"), "'"),
-                   "key"
-               )
+        allow_empty = FALSE,
+        msg = paste(
+            "invalid names for",
+            paste0("'", paste0(key, collapse = "$"), "'"),
+            "key"
+        )
     )
 
     return(res)
@@ -422,22 +454,22 @@
 
     # pre-condition
     .check_chr(s3_class,
-               allow_empty = FALSE, len_min = 1,
-               msg = "invalid 's3_class' parameter"
+        allow_empty = FALSE, len_min = 1,
+        msg = "invalid 's3_class' parameter"
     )
 
     if (!is.null(service)) {
         .check_chr(service,
-                   allow_empty = FALSE, len_min = 1, len_max = 1,
-                   msg = "invalid 'service' parameter"
+            allow_empty = FALSE, len_min = 1, len_max = 1,
+            msg = "invalid 'service' parameter"
         )
     }
 
     if (!is.null(url)) {
         .check_chr(url,
-                   allow_empty = FALSE, len_min = 1, len_max = 1,
-                   regex = '^(http|https)://[^ "]+$',
-                   msg = "invalid 'url' parameter"
+            allow_empty = FALSE, len_min = 1, len_max = 1,
+            regex = '^(http|https)://[^ "]+$',
+            msg = "invalid 'url' parameter"
         )
     }
 
@@ -446,11 +478,10 @@
     names(collections) <- toupper(names(collections))
 
     collections <- lapply(collections, function(collection) {
-
         # pre-condition
         .check_lst(collection,
-                   min_len = 1,
-                   msg = "invalid 'collections' parameter"
+            min_len = 1,
+            msg = "invalid 'collections' parameter"
         )
 
         # collection members must be lower case
@@ -495,21 +526,21 @@
 
     # check satellite
     .check_chr(satellite,
-               allow_null = TRUE,
-               msg = "invalid 'satellite' value"
+        allow_null = TRUE,
+        msg = "invalid 'satellite' value"
     )
 
     #  check sensor
     .check_chr(sensor,
-               allow_null = TRUE,
-               msg = "invalid 'sensor' value"
+        allow_null = TRUE,
+        msg = "invalid 'sensor' value"
     )
 
     # check metadata_search
     if (!missing(metadata_search)) {
         .check_chr_within(metadata_search,
-                          within = .conf("metadata_search_strategies"),
-                          msg = "invalid 'metadata_search' value"
+            within = .conf("metadata_search_strategies"),
+            msg = "invalid 'metadata_search' value"
         )
     }
 
@@ -521,11 +552,10 @@
     cloud_band <- bands[names(bands) %in% .source_cloud()]
 
     non_cloud_bands <- lapply(non_cloud_bands, function(band) {
-
         # pre-condition
         .check_lst(bands,
-                   min_len = 1,
-                   msg = "invalid 'bands' parameter"
+            min_len = 1,
+            msg = "invalid 'bands' parameter"
         )
 
         # bands' members are lower case
@@ -542,11 +572,10 @@
     })
 
     cloud_band <- lapply(cloud_band, function(cloud_band) {
-
         # pre-condition
         .check_lst(bands,
-                   min_len = 1,
-                   msg = "invalid 'bands' parameter"
+            min_len = 1,
+            msg = "invalid 'bands' parameter"
         )
 
         # bands' members are lower case
@@ -567,20 +596,20 @@
     .check_lst(dots, msg = "invalid extra arguments in collection")
 
     res <- c(list(bands = c(non_cloud_bands, cloud_band)),
-             "satellite" = satellite,
-             "sensor" = sensor,
-             "metadata_search" = metadata_search, dots
+        "satellite" = satellite,
+        "sensor" = sensor,
+        "metadata_search" = metadata_search, dots
     )
 
     # post-condition
     .check_lst(res,
-               min_len = 1,
-               msg = "invalid 'collection' value"
+        min_len = 1,
+        msg = "invalid 'collection' value"
     )
 
     .check_lst(res$bands,
-               min_len = 1,
-               msg = "invalid collection 'bands' value"
+        min_len = 1,
+        msg = "invalid collection 'bands' value"
     )
 
     # return a new collection data
@@ -607,7 +636,6 @@
                            offset_value,
                            band_name,
                            resolution, ...) {
-
     # pre-condition
     .check_num(
         x = missing_value,
@@ -679,8 +707,8 @@
 
     # post-condition
     .check_lst(res,
-               min_len = 7,
-               msg = "invalid 'band' value"
+        min_len = 7,
+        msg = "invalid 'band' value"
     )
 
     # return a band object
@@ -708,24 +736,24 @@
 
     # pre-condition
     .check_lgl(bit_mask,
-               len_min = 1, len_max = 1,
-               msg = "invalid 'bit_mask' parameter"
+        len_min = 1, len_max = 1,
+        msg = "invalid 'bit_mask' parameter"
     )
 
     .check_lst(values,
-               fn_check = .check_chr,
-               len_min = 1, len_max = 1,
-               msg = "invalid cloud 'values' parameter"
+        fn_check = .check_chr,
+        len_min = 1, len_max = 1,
+        msg = "invalid cloud 'values' parameter"
     )
 
     .check_num(interp_values,
-               len_min = 1, is_integer = TRUE,
-               msg = "invalid 'interp_values' parameter"
+        len_min = 1, is_integer = TRUE,
+        msg = "invalid 'interp_values' parameter"
     )
 
     .check_chr(band_name,
-               allow_empty = FALSE, len_min = 1, len_max = 1,
-               msg = "invalid 'band_name' value"
+        allow_empty = FALSE, len_min = 1, len_max = 1,
+        msg = "invalid 'band_name' value"
     )
 
     # extra parameters
@@ -742,15 +770,13 @@
 
     # post-condition
     .check_lst(res,
-               min_len = 5,
-               msg = "invalid 'band' value"
+        min_len = 5,
+        msg = "invalid 'band' value"
     )
 
     # return a cloud band object
     return(res)
 }
-
-
 #' @title Retrieve the rstac pagination limit
 #' @name .conf_rstac_limit
 #' @keywords internal
@@ -761,13 +787,12 @@
 
     # post-condition
     .check_num(res,
-               min = 1, len_min = 1, len_max = 1,
-               msg = "invalid 'rstac_pagination_limit' in config file"
+        min = 1, len_min = 1, len_max = 1,
+        msg = "invalid 'rstac_pagination_limit' in config file"
     )
 
     return(res)
 }
-
 #' @title Retrieve the raster package to be used
 #' @name .conf_raster_pkg
 #' @keywords internal
@@ -779,19 +804,18 @@
 
     # post-condition
     .check_chr(res,
-               len_min = 1, len_max = 1,
-               msg = "invalid 'raster_api_package' in config file"
+        len_min = 1, len_max = 1,
+        msg = "invalid 'raster_api_package' in config file"
     )
 
     .check_chr_within(res,
-                      within = .raster_supported_packages(),
-                      discriminator = "one_of",
-                      msg = "invalid 'raster_api_package' in config file"
+        within = .raster_supported_packages(),
+        discriminator = "one_of",
+        msg = "invalid 'raster_api_package' in config file"
     )
 
     return(res)
 }
-
 #' @title Basic access config functions
 #' @noRd
 #'
@@ -805,12 +829,11 @@
 #'
 #' @examples
 #' if (sits_run_examples()) {
-#' .conf_exists("run_tests") # TRUE
-#' .conf("run_tests")
-#' .conf_exists("not_existing_entry") # FALSE
+#'     .conf_exists("run_tests") # TRUE
+#'     .conf("run_tests")
+#'     .conf_exists("not_existing_entry") # FALSE
 #' }
 NULL
-
 #' @title Check if a key exists in config
 #' @noRd
 #' @param throw_error  Should an error be thrown if test fails?
@@ -851,21 +874,20 @@ NULL
 #'
 #' @examples
 #' if (sits_run_examples()) {
-#' # tests if 'BDC -> MOD13Q1-6 -> NDVI' key exists in config
-#' .conf_eo_band_exists(
-#'   source = "BDC",
-#'   collection = "MOD13Q1-6",
-#'   band = "NDVI"
-#' )
-#' # get configuration for band NDVI of 'BDC -> MOD13Q1-6' collection
-#' x <- .conf_eo_band(
-#'   source = "BDC",
-#'   collection = "MOD13Q1-6",
-#'   band = "NDVI"
-#' )
+#'     # tests if 'BDC -> MOD13Q1-6 -> NDVI' key exists in config
+#'     .conf_eo_band_exists(
+#'         source = "BDC",
+#'         collection = "MOD13Q1-6",
+#'         band = "NDVI"
+#'     )
+#'     # get configuration for band NDVI of 'BDC -> MOD13Q1-6' collection
+#'     x <- .conf_eo_band(
+#'         source = "BDC",
+#'         collection = "MOD13Q1-6",
+#'         band = "NDVI"
+#'     )
 #' }
 NULL
-
 #' @title Check if a band entry exists in config
 #' @noRd
 #' @param source  Data source.
@@ -886,7 +908,6 @@ NULL
     # Test for band and return
     .conf_exists("sources", source, "collections", collection, "bands", band)
 }
-
 #' @title Get a config value for a band
 #' @noRd
 #' @param source  Data source.
@@ -907,7 +928,6 @@ NULL
     # Get band config value and return it
     .conf("sources", source, "collections", collection, "bands", band)
 }
-
 #' @title Config functions for derived_cube
 #' @noRd
 #'
@@ -939,12 +959,11 @@ NULL
 #'
 #' @examples
 #' if (sits_run_examples()) {
-#' # get S3 class value that a derived_cube of class 'probs' must have
-#' .conf_derived_s3class("probs")
+#'     # get S3 class value that a derived_cube of class 'probs' must have
+#'     .conf_derived_s3class("probs")
 #' }
 #'
 NULL
-
 #' @title Get the S3 class values of a `derived_cube`
 #' @noRd
 #' @param derived_class  A `derived_cube` class name.
@@ -954,6 +973,16 @@ NULL
     derived_class <- tolower(derived_class)
     .conf("derived_cube", derived_class, "s3_class")
 }
+#' @title Get the S3 class values of a `vector_cube`
+#' @noRd
+#' @param vector_class  A `vector_cube` class name.
+#' @return A S3 class.
+.conf_vector_s3class <- function(vector_class) {
+    # derived_class is lowercase
+    vector_class <- tolower(vector_class)
+    .conf("vector_cube", vector_class, "s3_class")
+}
+
 #' @title Get a band configuration of a `derived_cube`
 #' @noRd
 #' @param derived_class  A `derived_cube` class name.
@@ -966,7 +995,6 @@ NULL
     derived_class <- tolower(derived_class)
     .conf("derived_cube", derived_class, "bands", band)
 }
-
 #' @title Band configuration accessors
 #' @noRd
 #'
@@ -978,7 +1006,6 @@ NULL
 #' to an eo_cube or derived_cube
 #'
 NULL
-
 #' @title Get the data type from a band configuration
 #' @param conf  A band definition value from config.
 #' @noRd
@@ -1035,13 +1062,19 @@ NULL
 .cloud_bit_mask <- function(conf) {
     .as_int(conf[["bit_mask"]][[1]])
 }
+#' @title Get the default parse info for local files  flag
+#' @noRd
+#' @param parse_info  Parse information set by user
+#' @param results_cube Is this a results cube?
+#' @return  Valid parse_info information
 .conf_parse_info <- function(parse_info, results_cube) {
     # is parse info NULL? use the default
     if (purrr::is_null(parse_info)) {
-        if (results_cube)
+        if (results_cube) {
             parse_info <- .conf("results_parse_info_def")
-        else
+        } else {
             parse_info <- .conf("local_parse_info_def")
+        }
     }
 
     # precondition - does the parse info have band and date?
@@ -1061,4 +1094,5 @@ NULL
             msg = "parse_info must include tile, date, and band."
         )
     }
+    return(parse_info)
 }
