@@ -1,5 +1,18 @@
+#' @title Test access to STAC collection
 #' @keywords internal
 #' @noRd
+#' @description
+#' These functions provide an API to handle/retrieve data from source's
+#' collections.
+#'
+#' @param source     Data source.
+#' @param collection Image collection.
+#' @param bands      Band names
+#' @param ...        Other parameters to be passed for specific types.
+#' @param start_date Start date.
+#' @param end_date   End date.
+#' @param dry_run    TRUE/FALSE
+#' @return           Called for side effects
 #' @export
 .source_collection_access_test.stac_cube <- function(source, collection,
                                                      bands, ...,
@@ -8,7 +21,7 @@
                                                      dry_run = FALSE) {
     # require package
     .check_require_packages("rstac")
-
+    # create a query
     items_query <- .stac_create_items_query(
         source = source,
         collection = collection,
@@ -16,7 +29,6 @@
         end_date = end_date,
         limit = 1
     )
-
     # assert that service is online
     tryCatch(
         {
@@ -58,11 +70,31 @@
             }
         )
     }
-    return(invisible(NULL))
+    return(invisible(source))
 }
-
+#' @title Function to instantiate a new cube from a source
 #' @keywords internal
 #' @noRd
+#' @description
+#' These functions provide an API to instantiate a new cube object and
+#' access/retrieve information from services or local files to fill
+#' cube attributes.
+#'
+#' A cube is formed by images (items) organized in tiles. To create a sits
+#' cube object (a \code{tibble}), a set of functions are called in order
+#' to retrieve metadata.
+#'
+#' @param source     Data source.
+#' @param collection Image collection.
+#' @param bands      Bands to be selected in the collection.
+#' @param tiles      A set of tiles in the collections reference system
+#' @param roi        Region of interest
+#' @param start_date Start date.
+#' @param end_date   End date.
+#' @param platform   Satellite platform
+#' @param progress   Show a progress bar?
+#' @param ...        Additional parameters.
+#' @return           New data cube
 #' @export
 .source_cube.stac_cube <- function(source,
                                    collection,
@@ -73,7 +105,6 @@
                                    end_date,
                                    platform,
                                    progress, ...) {
-
     # set caller to show in errors
     .check_set_caller(".source_cube.stac_cube")
 
@@ -121,9 +152,16 @@
     class(cube) <- .cube_s3class(cube)
     return(cube)
 }
-
+#' @title Select bands from a STAC item
 #' @keywords internal
 #' @noRd
+#'
+#' @param source     Data source
+#' @param items      STAC items
+#' @param bands      Bands to be selected in the collection.
+#' @param collection Image collection
+#' @param ...        Additional parameters.
+#' @return List of STAC items
 #' @export
 .source_items_bands_select.stac_cube <- function(source,
                                                  items,
@@ -144,16 +182,22 @@
     )
     return(items)
 }
-
+#' @title Create a new data cube based on STAC item
 #' @keywords internal
 #' @noRd
+#' @param source     Data source
+#' @param collection Image collection
+#' @param items      STAC items
+#' @param ...        Additional parameters.
+#' @param multicores Number of cores
+#' @param progress   Show progress bar?
+#' @return A data cube
 #' @export
 .source_items_cube.stac_cube <- function(source,
                                          collection = NULL,
                                          items, ...,
                                          multicores = 2,
                                          progress) {
-
     # set caller to show in errors
     .check_set_caller(".source_items_cube.stac_cube")
 
@@ -180,7 +224,6 @@
         data <- data |>
             tidyr::nest(items = c("fid", "features"))
     } else {
-
         # item by item
         data <- data |>
             dplyr::transmute(
@@ -198,7 +241,6 @@
 
     # do parallel requests
     tiles <- .parallel_map(seq_len(nrow(data)), function(i) {
-
         # get tile name
         tile <- data[["tile"]][[i]]
         # get fids
@@ -238,7 +280,8 @@
         # check if metadata was retrieved
         if (is.null(asset_info)) {
             warning("cannot open files:\n", paste(paths, collapse = ", "),
-                    call. = FALSE)
+                call. = FALSE
+            )
             return(NULL)
         }
         # generate file_info
@@ -267,6 +310,7 @@
                 item = item,
                 collection = collection, ...
             )
+            cloud_cover <- .default(cloud_cover, 0)
             # post-conditions
             .check_na(date, msg = "invalid date value")
             .check_length(date,
@@ -305,7 +349,9 @@
                 # check if metadata was retrieved
                 if (is.null(asset_info)) {
                     warning("cannot open files:\n",
-                            paste(paths, collapse = ", "), call. = FALSE)
+                        paste(paths, collapse = ", "),
+                        call. = FALSE
+                    )
                     return(NULL)
                 }
             }
@@ -376,9 +422,10 @@
 
     # prepare cube
     cube <- cube |>
-        tidyr::nest(file_info = -dplyr::matches(c("tile", "crs"))) |>
+        dplyr::mutate(crs2 = .data[["crs"]]) |>
+        tidyr::nest(file_info = -dplyr::matches(c("tile", "crs2"))) |>
+        dplyr::rename(crs = "crs2") |>
         slider::slide_dfr(function(tile) {
-
             # get file_info
             file_info <- tile[["file_info"]][[1]]
             # arrange file_info
@@ -412,9 +459,14 @@
         })
     return(cube)
 }
-
+#' @title Get date from STAC item
 #' @keywords internal
 #' @noRd
+#' @param source     Data source
+#' @param item       STAC item
+#' @param ...        Additional parameters.
+#' @param collection Image collection
+#' @return List of dates
 #' @export
 .source_item_get_date.stac_cube <- function(source,
                                             item, ...,
@@ -423,9 +475,14 @@
         lubridate::as_date(item[[c("properties", "datetime")]])
     )
 }
-
+#' @title Get href from STAC item
 #' @keywords internal
 #' @noRd
+#' @param source     Data source
+#' @param item       STAC item
+#' @param ...        Additional parameters.
+#' @param collection Image collection
+#' @return HTTP references
 #' @export
 .source_item_get_hrefs.stac_cube <- function(source,
                                              item, ...,
@@ -437,34 +494,43 @@
     hrefs <- .stac_add_gdal_fs(hrefs)
     return(hrefs)
 }
-
+#' @title Get cloud cover from STAC item
 #' @keywords internal
 #' @noRd
+#' @param source     Data source
+#' @param ...        Additional parameters.
+#' @param item       STAC item
+#' @param collection Image collection
+#' @return Cloud cover value
 #' @export
 .source_item_get_cloud_cover.stac_cube <- function(source, ...,
                                                    item,
                                                    collection = NULL) {
     item[["properties"]][["eo:cloud_cover"]]
 }
-
+#' @title Get bands from STAC item
 #' @keywords internal
 #' @noRd
+#' @param source     Data source
+#' @param item       STAC item
+#' @param ...        Additional parameters.
+#' @param collection Image collection
+#' @return Band names
 #' @export
 .source_item_get_bands.stac_cube <- function(source,
                                              item, ...,
                                              collection = NULL) {
     names(item[["assets"]])
 }
-
-#' @rdname source_cube
+#' @title Get bbox from file info
 #' @keywords internal
 #' @noRd
-#' @description \code{.source_tile_get_bbox()} retrieves the bounding
-#' box from items of a tile.
-#'
-#' @return \code{.source_tile_get_bbox()} returns a \code{list}
-#' vector with 4 elements (xmin, ymin, xmax, ymax).
-#'
+#' @param source     Data source
+#' @param file_info  File info
+#' @param ...        Additional parameters.
+#' @param collection Image collection
+#' @return vector (xmin, ymin, xmax, ymax).
+#' @export
 .source_tile_get_bbox.stac_cube <- function(source,
                                             file_info, ...,
                                             collection = NULL) {
@@ -492,9 +558,14 @@
     bbox <- c(xmin = xmin, ymin = ymin, xmax = xmax, ymax = ymax)
     return(bbox)
 }
-
+#' @title Get file ID from STAC item
 #' @keywords internal
 #' @noRd
+#' @param source     Data source
+#' @param item       STAC item
+#' @param ...        Additional parameters.
+#' @param collection Image collection
+#' @return File IDs
 #' @export
 .source_items_fid.stac_cube <- function(source,
                                         items, ...,
@@ -505,6 +576,21 @@
         len_min = length(fid), len_max = length(fid),
         msg = "invalid feature id value"
     )
-
     return(fid)
 }
+#' @noRd
+#' @title Configure access.
+#' @param source  Data source
+#' @param collection Image collection
+#' @return No return, called for side effects
+.source_configure_access.stac_cube <- function(source, collection) {
+    return(invisible(source))
+}
+#' @title Adjusts date-time if required by source
+#' @noRd
+#' @param source  Data source
+#' @param date    Date to be adjusted
+#' @return Adjusted date
+.source_adjust_date.stac_cube <- function(source, date) {
+    return(date)
+}
