@@ -4,23 +4,22 @@
 #' @description Predictors are X-Y values required for machine learning
 #' algorithms, organized as a data table where each row corresponds
 #' to a training sample. The first two columns of the predictors table
-#' are categorical ("label_id" and "label"). The other columns are
+#' are categorical (\code{label_id} and \code{label}). The other columns are
 #' the values of each band and time, organized first by band and then by time.
 #'
-#' @param  samples     Time series in sits format
+#' @param  samples     Time series in sits format (tibble of class "sits")
 #'
 #' @return The predictors for the sample: a data.frame with one row per sample.
 #'
-#' @note
-#' Please refer to the sits documentation available in
-#' <https://e-sensing.github.io/sitsbook/> for detailed examples.
 #' @examples
 #' if (sits_run_examples()) {
-#'      pred <- sits_predictors(samples_modis_ndvi)
+#'     pred <- sits_predictors(samples_modis_ndvi)
 #' }
 #'
 #' @export
 sits_predictors <- function(samples) {
+    .check_valid(samples)
+    samples <- .check_samples_ts(samples)
     pred <- .predictors(samples)
     return(pred)
 }
@@ -35,7 +34,7 @@ sits_predictors <- function(samples) {
 #' the values of each band and time, organized first by band and then by time.
 #' This function returns the numeric values associated to each sample.
 #'
-#' @param  pred    X-Y predictors: a data.table with one row per sample.
+#' @param  pred    X-Y predictors: a data.frame with one row per sample.
 #'
 #' @return The Y predictors for the sample: data.frame with one row per sample.
 #'
@@ -44,10 +43,9 @@ sits_predictors <- function(samples) {
 #' <https://e-sensing.github.io/sitsbook/> for detailed examples.
 #' @examples
 #' if (sits_run_examples()) {
-#'      pred <- sits_predictors(samples_modis_ndvi)
-#'      features <- sits_pred_features(pred)
+#'     pred <- sits_predictors(samples_modis_ndvi)
+#'     features <- sits_pred_features(pred)
 #' }
-#'
 #' @export
 sits_pred_features <- function(pred) {
     features <- .pred_features(pred)
@@ -63,17 +61,14 @@ sits_pred_features <- function(pred) {
 #' the values of each band and time, organized first by band and then by time.
 #' This function returns the numeric values associated to each sample.
 #'
-#' @param  pred    X-Y predictors: a data.table with one row per sample.
+#' @param  pred    X-Y predictors: a data.frame with one row per sample.
 #'
-#' @return The label associated to each training sample.
+#' @return A character vector with labels associated to training samples.
 #'
-#' @note
-#' Please refer to the sits documentation available in
-#' <https://e-sensing.github.io/sitsbook/> for detailed examples.
 #' @examples
 #' if (sits_run_examples()) {
-#'      pred <- sits_predictors(samples_modis_ndvi)
-#'      ref  <- sits_pred_references(pred)
+#'     pred <- sits_predictors(samples_modis_ndvi)
+#'     ref <- sits_pred_references(pred)
 #' }
 #' @export
 sits_pred_references <- function(pred) {
@@ -88,22 +83,25 @@ sits_pred_references <- function(pred) {
 #' To normalize the predictors, it is required that the statistics per band
 #' for each sample have been obtained by the "sits_stats" function.
 #'
-#' @param  pred    X-Y predictors: a data.table with one row per sample.
-#' @param  stats   Output of the "sits_stats()" applied to the samples.
+#' @param  pred    X-Y predictors: a data.frame with one row per sample.
+#' @param  stats   Values of time series for Q02 and Q98 of the data
+#'                 (list of numeric values with two elements)
 #'
-#' @return A normalized set of predictor values
+#' @return A data.frame with normalized predictor values
 #'
 #' @note
 #' Please refer to the sits documentation available in
 #' <https://e-sensing.github.io/sitsbook/> for detailed examples.
 #' @examples
 #' if (sits_run_examples()) {
-#'      stats <- sits_stats(samples_modis_ndvi)
-#'      pred <- sits_predictors(samples_modis_ndvi)
-#'      pred_norm <- sits_pred_normalize(pred, stats)
+#'     stats <- sits_stats(samples_modis_ndvi)
+#'     pred <- sits_predictors(samples_modis_ndvi)
+#'     pred_norm <- sits_pred_normalize(pred, stats)
 #' }
 #' @export
 sits_pred_normalize <- function(pred, stats) {
+    .check_valid(pred)
+    .check_valid(stats)
     pred <- .pred_normalize(pred, stats)
     return(pred)
 }
@@ -116,18 +114,18 @@ sits_pred_normalize <- function(pred, stats) {
 #' This function extracts a fraction of the predictors to serve as test values
 #' for the deep learning algorithm.
 #'
-#' @param  pred    X-Y predictors: a data.table with one row per sample.
-#' @param  frac   Fraction of the X-Y predictors to be extracted
+#' @param  pred    X-Y predictors: a data.frame with one row per sample.
+#' @param  frac    Fraction of the X-Y predictors to be extracted
 #'
-#' @return A fraction of the X-Y predictors.
+#' @return A data.frame with the chosen fraction of the X-Y predictors.
 #'
 #' @note
 #' Please refer to the sits documentation available in
 #' <https://e-sensing.github.io/sitsbook/> for detailed examples.
 #' @examples
 #' if (sits_run_examples()) {
-#'      pred <- sits_predictors(samples_modis_ndvi)
-#'      pred_frac <- sits_pred_sample(pred, frac = 0.5)
+#'     pred <- sits_predictors(samples_modis_ndvi)
+#'     pred_frac <- sits_pred_sample(pred, frac = 0.5)
 #' }
 #' @export
 sits_pred_sample <- function(pred, frac) {
@@ -155,7 +153,7 @@ sits_pred_sample <- function(pred, frac) {
 #' <https://e-sensing.github.io/sitsbook/> for detailed examples.
 #' @examples
 #' if (sits_run_examples()) {
-#'      stats <- sits_stats(samples_modis_ndvi)
+#'     stats <- sits_stats(samples_modis_ndvi)
 #' }
 #' @export
 sits_stats <- function(samples) {
