@@ -39,27 +39,16 @@
 #'     # for the Mato Grosso state in Brasil
 #'     # create a list to store the results
 #'     results <- list()
-#'
 #'     # accuracy assessment lightTAE
-#'     acc_ltae <- sits_kfold_validate(
-#'         samples_modis_ndvi,
-#'         folds = 5,
-#'         ml_method = sits_lighttae()
-#'     )
-#'     # use a name
-#'     acc_ltae$name <- "LightTAE"
-#'     # put the result in a list
-#'     results[[length(results) + 1]] <- acc_ltae
-#'
-#'     # Machine Learning - Random Forests
-#'     acc_rf <- sits_kfold_validate(
+#'     acc_rfor <- sits_kfold_validate(
 #'         samples_modis_ndvi,
 #'         folds = 5,
 #'         ml_method = sits_rfor()
 #'     )
-#'     acc_rf$name <- "RandomForests"
+#'     # use a name
+#'     acc_rfor$name <- "Rfor"
 #'     # put the result in a list
-#'     results[[length(results) + 1]] <- acc_rf
+#'     results[[length(results) + 1]] <- acc_rfor
 #'     # save to xlsx file
 #'     sits_to_xlsx(
 #'         results,
@@ -72,53 +61,44 @@ sits_kfold_validate <- function(samples,
                                 folds = 5,
                                 ml_method = sits_rfor(),
                                 multicores = 2) {
-
     # set caller to show in errors
     .check_set_caller("sits_kfold_validate")
-
     # require package
     .check_require_packages("caret")
-
     # pre-condition
     .check_that(
         inherits(ml_method, "function"),
         local_msg = "ml_method is not a valid sits method",
         msg = "invalid ml_method parameter"
     )
-
     # pre-condition
-    .check_multicores(multicores)
-
+    .check_multicores(multicores, min = 1, max = 2048)
     # For now, torch models does not support multicores in Windows
     if (multicores > 1 && .Platform$OS.type == "windows" &&
         "optimizer" %in% ls(environment(ml_method))) {
         multicores <- 1
-        if (.check_warnings())
+        if (.check_warnings()) {
             warning("sits_kfold_validate() works
                     only with 1 core in Windows OS.",
                 call. = FALSE,
                 immediate. = TRUE
             )
+        }
     }
-
     # Get labels from samples
     labels <- .samples_labels(samples)
     # Create numeric labels vector
     code_labels <- seq_along(labels)
     names(code_labels) <- labels
-
     # Is the data labelled?
     .check_that(
         x = !("NoClass" %in% labels),
         msg = "requires labelled set of time series"
     )
-
     # start parallel process
     multicores <- min(multicores, folds)
-
     .parallel_start(workers = multicores)
     on.exit(.parallel_stop())
-
     # Create partitions different splits of the input data
     samples <- .samples_create_folds(samples, folds = folds)
     # Do parallel process
@@ -140,20 +120,15 @@ sits_kfold_validate <- function(samples,
         remove(ml_model)
         return(list(pred = values, ref = .pred_references(pred_test)))
     }, n_retries = 0, progress = FALSE)
-
+    # create predicted and reference vectors
     pred <- unlist(lapply(conf_lst, function(x) x$pred))
     ref <- unlist(lapply(conf_lst, function(x) x$ref))
-
-    # call caret to provide assessment
     unique_ref <- unique(ref)
     pred_fac <- factor(pred, levels = unique_ref)
     ref_fac <- factor(ref, levels = unique_ref)
-
     # call caret package to the classification statistics
     acc <- caret::confusionMatrix(pred_fac, ref_fac)
-
     class(acc) <- c("sits_accuracy", class(acc))
-
     return(acc)
 }
 #' @title Validate time series samples
@@ -176,41 +151,57 @@ sits_kfold_validate <- function(samples,
 #'
 #' This function returns the confusion matrix, and Kappa values.
 #'
-#' @param samples            Time series set to be validated.
-#' @param samples_validation Time series set used for validation.
+#' @param samples            Time series to be validated (class "sits").
+#' @param samples_validation Optional: Time series used for validation
+#'                           (class "sits")
 #' @param validation_split   Percent of original time series set to be used
-#'                           for validation (if samples_validation is NULL)
-#' @param ml_method          Machine learning method.
+#'                           for validation if samples_validation is NULL
+#'                           (numeric value).
+#' @param ml_method          Machine learning method (function)
 #'
 #' @return A \code{caret::confusionMatrix} object to be used for
 #'         validation assessment.
 #'
 #' @examples
-#' if (sits_run_examples()){
-#'    conf_matrix <- sits_validate(cerrado_2classes)
+#' if (sits_run_examples()) {
+#'     samples <- sits_sample(cerrado_2classes, frac = 0.5)
+#'     samples_validation <- sits_sample(cerrado_2classes, frac = 0.5)
+#'     conf_matrix_1 <- sits_validate(
+#'          samples = samples,
+#'          samples_validation = samples_validation,
+#'          ml_method = sits_rfor()
+#'    )
+#'    conf_matrix_2 <- sits_validate(
+#'          samples = cerrado_2classes,
+#'          validation_split = 0.2,
+#'          ml_method = sits_rfor()
+#'    )
+
 #' }
 #' @export
 sits_validate <- function(samples,
                           samples_validation = NULL,
                           validation_split = 0.2,
                           ml_method = sits_rfor()) {
-
     # set caller to show in errors
     .check_set_caller("sits_validate")
-
     # require package
     .check_require_packages("caret")
-
-    # pre-condition
+    # check samples
+    .check_samples_train(samples)
+    # check validation
+    if (!is.null(samples_validation)) {
+        .check_samples_train(samples_validation)
+    }
+    # check validation split
+    .check_num(validation_split, min = 0, max = 1, len_min = 1, len_max = 1)
+    # pre-condition for ml_method
     .check_that(
         inherits(ml_method, "function"),
         local_msg = "ml_method is not a valid sits method",
         msg = "invalid ml_method parameter"
     )
-
-    # is the data labelled?
-    .check_samples_train(samples)
-
+    # Are there samples for validation?
     if (is.null(samples_validation)) {
         samples <- .tibble_samples_split(
             samples = samples,
@@ -219,7 +210,6 @@ sits_validate <- function(samples,
         samples_validation <- dplyr::filter(samples, !.data[["train"]])
         samples <- dplyr::filter(samples, .data[["train"]])
     }
-
     # create a machine learning model
     ml_model <- sits_train(samples = samples, ml_method = ml_method)
     # Convert samples time series in predictors and preprocess data
