@@ -16,8 +16,11 @@
 #' @param  tiles         Tiles to be plotted (in case of a multi-tile cube).
 #' @param  class_cube    Classified cube to be overlayed on top on image.
 #' @param  legend        Named vector that associates labels to colors.
-#' @param  color_palette Palette provided in the configuration file.
-#' @param  segments      Segment list produced by \link{sits_segment}
+#' @param  palette       Color palette (if colors not in legend nor
+#'                       in sits default colors)
+#' @param  opacity       Opacity of segment fill or class cube
+#' @param  seg_color     Color for segment boundaries
+#' @param  line_width    Line width for segments (in pixels)
 #' @param  view_max_mb   Maximum size of leaflet to be visualized
 #' @param  id_neurons    Neurons from the SOM map to be shown.
 #'
@@ -32,7 +35,7 @@
 #' if (sits_run_examples()) {
 #'     # view samples
 #'     sits_view(cerrado_2classes)
-#'.    # create a local data cube
+#'     # create a local data cube
 #'     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
 #'     modis_cube <- sits_cube(
 #'         source = "BDC",
@@ -45,7 +48,7 @@
 #'     )
 #'     # train a model
 #'     rf_model <- sits_train(samples_modis_ndvi, sits_rfor())
-#'.    # classify the cube
+#'     # classify the cube
 #'     modis_probs <- sits_classify(
 #'         data = modis_cube,
 #'         ml_model = rf_model,
@@ -58,9 +61,9 @@
 #'         modis_probs,
 #'         output_dir = tempdir()
 #'     )
-#'.    # view the classified map
+#'     # view the classified map
 #'     sits_view(modis_label)
-#'.    # view the classified map with the B/W image
+#'     # view the classified map with the B/W image
 #'     sits_view(modis_cube,
 #'         band = "NDVI",
 #'         class_cube = modis_label,
@@ -79,74 +82,9 @@
 #'     )
 #'     # view the uncertainty cube
 #'     sits_view(modis_uncert)
-#'
-#'     # segment the image
-#'     segments <- sits_segment(
-#'         cube = modis_cube,
-#'         tile = "012010",
-#'         bands = "NDVI",
-#'         date = sits_timeline(modis_cube)[1],
-#'         seg_fn = sits_slic(step = 20)
-#'     )
-#'     # view image and segments
-#'     sits_view (
-#'         modis_cube,
-#'         band = "NDVI",
-#'         segments = segments
-#'     )
-#'     # view image, classified image and segments
-#'     sits_view (
-#'         modis_cube,
-#'         red = "NDVI",
-#'         green = "NDVI",
-#'         blue = "NDVI",
-#'         class_cube = modis_label,
-#'         segments = segments
-#'     )
-#'     # view B/W image, classified image and segments
-#'     sits_view (
-#'         modis_cube,
-#'         band = "NDVI",
-#'         class_cube = modis_label,
-#'         segments = segments
-#'     )
-#'     # get the average value per segment
-#'     samples_seg <- sits_get_data(
-#'         cube = modis_cube,
-#'         samples = segments
-#'     )
-#'     # train a model
-#'     tcnn_model <- sits_train(samples_modis_ndvi, sits_tempcnn())
-#'     # classify the segments
-#'     seg_class <- sits_classify(
-#'         data = samples_seg,
-#'         ml_model = tcnn_model
-#'     )
-#'
-#'     # add a column to the segments by class
-#'     segments <- sits_join_segments(
-#'         data = seg_class,
-#'         segments = segments
-#'     )
-#'     # view image and classified segments
-#'     sits_view (
-#'         modis_cube,
-#'         band = "NDVI",
-#'         segments = segments
-#'     )
-#'     # view image, classified image and segments
-#'     sits_view (
-#'         modis_cube,
-#'         red = "NDVI",
-#'         green = "NDVI",
-#'         blue = "NDVI",
-#'         class_cube = modis_label,
-#'         segments = segments
-#'     )
 #' }
 #' @export
 sits_view <- function(x, ...) {
-
     # set caller to show in errors
     .check_set_caller("sits_view")
     UseMethod("sits_view", x)
@@ -156,8 +94,7 @@ sits_view <- function(x, ...) {
 #' @export
 sits_view.sits <- function(x, ...,
                            legend = NULL,
-                           color_palette = "Harmonic") {
-
+                           palette = "Harmonic") {
     # precondition
     .check_require_packages("leaflet")
 
@@ -166,12 +103,14 @@ sits_view.sits <- function(x, ...,
         colnames(x),
         contains = c("longitude", "latitude", "label"),
         discriminator = "all_of",
-        msg = "Missing lat/long and label - please correct")
+        msg = "Missing lat/long and label - please correct"
+    )
+    # create a leaflet for samples
     leaf_map <- .view_samples(
         samples = x,
         legend = legend,
-        color_palette = color_palette)
-
+        palette = palette
+    )
     return(leaf_map)
 }
 #' @rdname   sits_view
@@ -179,20 +118,17 @@ sits_view.sits <- function(x, ...,
 #' @export
 sits_view.data.frame <- function(x, ...,
                                  legend = NULL,
-                                 color_palette = "Harmonic") {
-    leaf_map <- sits_view.sits(x, legend, color_palette)
-
+                                 palette = "Harmonic") {
+    leaf_map <- sits_view.sits(x, legend, palette)
     return(leaf_map)
 }
 #' @rdname   sits_view
 #'
 #' @export
-#'
 sits_view.som_map <- function(x, ...,
                               id_neurons,
                               legend = NULL,
-                              color_palette = "Harmonic") {
-
+                              palette = "Harmonic") {
     # check id_neuron
     .check_int_parameter(
         id_neurons,
@@ -208,8 +144,8 @@ sits_view.som_map <- function(x, ...,
     leaf_map <- .view_samples(
         samples = samples,
         legend = legend,
-        color_palette = color_palette)
-
+        palette = palette
+    )
     return(leaf_map)
 }
 #' @rdname   sits_view
@@ -224,20 +160,21 @@ sits_view.raster_cube <- function(x, ...,
                                   dates = NULL,
                                   class_cube = NULL,
                                   legend = NULL,
-                                  color_palette = "RdYlGn",
-                                  segments = NULL,
+                                  palette = "RdYlGn",
+                                  opacity = 0.7,
                                   view_max_mb = NULL) {
     # preconditions
     # Probs cube not supported
     .check_that(!inherits(x, "probs_cube"),
-                local_msg = paste0("sits_view not available for probability cube")
+        local_msg = paste0("sits_view not available for probability cube")
     )
     # verifies if leafem and leaflet packages are installed
     .check_require_packages(c("leafem", "leaflet"))
     # pre-condition for bands
+    .check_view_bands_params(band, red, green, blue)
     .check_view_bands(x, band, red, green, blue)
-    # grayscale or RGB?
-    leaf_map <- .view_image(
+    # view image raster
+    leaf_map <- .view_image_raster(
         cube = x,
         class_cube = class_cube,
         tiles = tiles,
@@ -247,8 +184,52 @@ sits_view.raster_cube <- function(x, ...,
         green = green,
         blue = blue,
         legend = legend,
-        color_palette = color_palette,
-        segments = segments,
+        palette = palette,
+        opacity = opacity,
+        view_max_mb = view_max_mb
+    )
+    return(leaf_map)
+}
+#' @rdname   sits_view
+#'
+#' @export
+sits_view.vector_cube <- function(x, ...,
+                                  band = NULL,
+                                  red = NULL,
+                                  green = NULL,
+                                  blue = NULL,
+                                  tiles = x$tile,
+                                  dates = NULL,
+                                  class_cube = NULL,
+                                  legend = NULL,
+                                  palette = "RdYlGn",
+                                  opacity = 0.7,
+                                  seg_color = "black",
+                                  line_width = 1,
+                                  view_max_mb = NULL) {
+    # preconditions
+    .check_that(inherits(x, "vector_cube"),
+                local_msg = paste0("cube is not a vector cube")
+    )
+    # verifies if leafem and leaflet packages are installed
+    .check_require_packages(c("leafem", "leaflet"))
+    # pre-condition for bands
+    .check_view_bands(x, band, red, green, blue)
+    # view vector cube
+    leaf_map <- .view_image_vector(
+        cube = x,
+        tiles = tiles,
+        dates = dates,
+        band = band,
+        red = red,
+        green = green,
+        blue = blue,
+        class_cube = class_cube,
+        legend = legend,
+        palette = palette,
+        opacity = opacity,
+        seg_color = seg_color,
+        line_width = line_width,
         view_max_mb = view_max_mb
     )
     return(leaf_map)
@@ -260,14 +241,14 @@ sits_view.uncertainty_cube <- function(x, ...,
                                        tiles = x$tile,
                                        class_cube = NULL,
                                        legend = NULL,
-                                       color_palette = "Blues",
-                                       segments = NULL,
+                                       palette = "Blues",
+                                       opacity = 0.7,
                                        view_max_mb = NULL) {
     # preconditions
     # verifies if leafem and leaflet packages are installed
     .check_require_packages(c("leafem", "leaflet"))
     # plot as grayscale
-    band   <- .cube_bands(x)
+    band <- .cube_bands(x)
     # try to find tiles in the list of tiles of the cube
     .check_chr_within(
         tiles,
@@ -276,11 +257,10 @@ sits_view.uncertainty_cube <- function(x, ...,
     )
     # filter the tiles to be processed
     cube <- .cube_filter_tiles(x, tiles)
-
     # more than one tile? needs regular cube
-    if (nrow(cube) > 1)
+    if (nrow(cube) > 1) {
         .check_is_regular(cube)
-
+    }
     # check the view_max_mb parameter
     view_max_mb <- .view_set_max_mb(view_max_mb)
     # find out if resampling is required (for big images)
@@ -291,9 +271,8 @@ sits_view.uncertainty_cube <- function(x, ...,
     )
     # create a leaflet and add providers
     leaf_map <- .view_add_basic_maps()
-    # get names of basic maps
+    # get names of base maps
     base_maps <- .view_get_base_maps(leaf_map)
-
     # obtain the raster objects for the dates chosen
     for (row in seq_len(nrow(cube))) {
         # get tile
@@ -304,7 +283,8 @@ sits_view.uncertainty_cube <- function(x, ...,
             band_file = band_file,
             tile = tile,
             band = .cube_bands(cube),
-            color_palette = color_palette,
+            date = NULL,
+            palette = palette,
             output_size = output_size
         )
     }
@@ -314,7 +294,8 @@ sits_view.uncertainty_cube <- function(x, ...,
         class_cube = class_cube,
         tiles = tiles,
         legend = legend,
-        color_palette = color_palette,
+        palette = palette,
+        opacity = opacity,
         output_size = output_size
     )
     # add overlay groups
@@ -323,7 +304,7 @@ sits_view.uncertainty_cube <- function(x, ...,
         class_cube = class_cube
     )
     # add layers control to leafmap
-    leaf_map <- leaf_map  |>
+    leaf_map <- leaf_map |>
         leaflet::addLayersControl(
             baseGroups = base_maps,
             overlayGroups = overlay_groups,
@@ -331,15 +312,12 @@ sits_view.uncertainty_cube <- function(x, ...,
         ) |>
         # add legend to leaf_map
         .view_add_legend(
-            class_cube = class_cube,
-            segments = segments,
+            cube = class_cube,
             legend = legend,
-            color_palette = color_palette
+            palette = palette
         )
     return(leaf_map)
 }
-
-
 #' @rdname sits_view
 #'
 #' @export
@@ -347,12 +325,11 @@ sits_view.uncertainty_cube <- function(x, ...,
 sits_view.class_cube <- function(x, ...,
                                  tiles = NULL,
                                  legend = NULL,
-                                 color_palette = "Spectral",
-                                 segments = NULL,
+                                 palette = "Spectral",
+                                 opacity = 0.8,
                                  view_max_mb = NULL) {
     # preconditions
     .check_require_packages("leaflet")
-
     # deal with tiles
     if (!purrr::is_null(tiles)) {
         # try to find tiles in the list of tiles of the cube
@@ -382,27 +359,23 @@ sits_view.class_cube <- function(x, ...,
             class_cube = cube,
             tiles = tiles,
             legend = legend,
-            color_palette = color_palette,
-            output_size = output_size) |>
-        # add segments
-        .view_segments(
-            segments = segments,
-            legend = legend,
-            color_palette = color_palette) |>
+            palette = palette,
+            opacity = opacity,
+            output_size = output_size
+        ) |>
         # add legend
         .view_add_legend(
-            class_cube = cube,
+            cube = cube,
             legend = legend,
-            color_palette = color_palette,
-            segments = segments)
+            palette = palette
+        )
 
     # add overlay groups
     overlay_groups <- .view_add_overlay_grps(
-        class_cube = cube,
-        segments = segments
+        cube = cube
     )
     # add layers control
-    leaf_map <- leaf_map  |>
+    leaf_map <- leaf_map |>
         leaflet::addLayersControl(
             baseGroups = base_maps,
             overlayGroups = overlay_groups,
@@ -419,13 +392,14 @@ sits_view.probs_cube <- function(x, ...,
                                  class_cube = NULL,
                                  legend = NULL,
                                  view_max_mb = NULL,
-                                 color_palette = "YlGnBu") {
+                                 opacity = 0.7,
+                                 palette = "YlGnBu") {
     # preconditions
     # verifies if leafem and leaflet packages are installed
     .check_require_packages(c("leafem", "leaflet"))
     # get band and labels
     band <- .cube_bands(x)
-    labels  <- .cube_labels(x)
+    labels <- .cube_labels(x)
     # try to find tiles in the list of tiles of the cube
     .check_chr_within(
         tiles,
@@ -436,9 +410,9 @@ sits_view.probs_cube <- function(x, ...,
     cube <- .cube_filter_tiles(x, tiles)
 
     # more than one tile? needs regular cube
-    if (nrow(cube) > 1)
+    if (nrow(cube) > 1) {
         .check_is_regular(cube)
-
+    }
     # check the view_max_mb parameter
     view_max_mb <- .view_set_max_mb(view_max_mb)
     # find out if resampling is required (for big images)
@@ -476,7 +450,7 @@ sits_view.probs_cube <- function(x, ...,
                 leaf_map,
                 x = st_obj_new,
                 band = ind,
-                colors = color_palette,
+                colors = palette,
                 project = FALSE,
                 group = paste("probs", labels[[ind]]),
                 maxBytes = output_size["leaflet_maxbytes"]
@@ -489,15 +463,20 @@ sits_view.probs_cube <- function(x, ...,
             class_cube = class_cube,
             tiles = tiles,
             legend = legend,
-            color_palette = color_palette,
-            output_size = output_size) |>
+            palette = palette,
+            opacity = opacity,
+            output_size = output_size
+        ) |>
         # add legend
-        .view_add_legend(class_cube = cube)
+        .view_add_legend(cube = cube,
+                         legend = legend,
+                         palette = palette)
 
     # set overlay groups
     overlay_groups <- paste("probs", labels)
-    if (!purrr::is_null(class_cube))
+    if (!purrr::is_null(class_cube)) {
         overlay_groups <- c(overlay_groups, "classification")
+    }
     # add layers control to leafmap
     leaf_map <- leaf_map |>
         leaflet::addLayersControl(
@@ -505,7 +484,6 @@ sits_view.probs_cube <- function(x, ...,
             overlayGroups = overlay_groups,
             options = leaflet::layersControlOptions(collapsed = FALSE)
         )
-
     return(leaf_map)
 }
 #' @rdname sits_view
