@@ -3,11 +3,12 @@ devAskNewPage(ask = FALSE)
 # load the sits library
 library(sits)
 if (!requireNamespace("sitsdata", quietly = TRUE)) {
-    stop(paste0(
-        "Please install package sitsdata\n",
-        "Please call devtools::install_github('e-sensing/sitsdata')"
-    ),
-    call. = FALSE
+    stop(
+        paste0(
+            "Please install package sitsdata\n",
+            "Please call devtools::install_github('e-sensing/sitsdata')"
+        ),
+        call. = FALSE
     )
 }
 
