@@ -8,8 +8,11 @@ test_that("Single core classification with rfor", {
         source = "BDC",
         collection = "MOD13Q1-6",
         data_dir = data_dir,
-        progress = FALSE
+        progress = TRUE,
+        verbose = TRUE
     )
+    expect_error(.check_bbox(sinop))
+
     output_dir <- paste0(tempdir(), "/single_rfor")
     if (!dir.exists(output_dir)) {
         dir.create(output_dir)
@@ -22,20 +25,24 @@ test_that("Single core classification with rfor", {
         multicores = 1,
         progress = FALSE
     )
+    bands_p <- sits_bands(sinop_probs)
+    labels_p <- sits_labels(sinop_probs)
+    expect_true(.check_cube_is_results_cube(bands_p, labels_p))
 
     # testing resume feature
     out <- capture_messages({
         expect_message(
-        object = {
-            sits_classify(
-                data = sinop,
-                ml_model = rfor_model,
-                output_dir = output_dir,
-                memsize = 4,
-                multicores = 2,
-                progress = TRUE
-            )},
-        regexp = "Recovery: "
+            object = {
+                sits_classify(
+                    data = sinop,
+                    ml_model = rfor_model,
+                    output_dir = output_dir,
+                    memsize = 4,
+                    multicores = 2,
+                    progress = TRUE
+                )
+            },
+            regexp = "Recovery: "
         )
     })
     expect_true(grepl("output_dir", out[1]))
@@ -45,7 +52,7 @@ test_that("Single core classification with rfor", {
         "Pastagem", "Soja_Milho"
     )
     expect_true(all(sits_labels(sinop_probs) %in%
-                        c("Cerrado", "Floresta", "Pastagem", "Soja_Milho")))
+        c("Cerrado", "Floresta", "Pastagem", "Soja_Milho")))
     expect_true(all(file.exists(unlist(sinop_probs$file_info[[1]]$path))))
     r_obj <- .raster_open_rast(sinop_probs$file_info[[1]]$path[[1]])
 
@@ -61,7 +68,6 @@ test_that("Single core classification with rfor", {
 })
 
 test_that("Classification with SVM", {
-
     svm_model <- sits_train(samples_modis_ndvi, sits_svm())
 
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
@@ -96,8 +102,8 @@ test_that("Classification with SVM", {
 
     expect_true(all(file.remove(unlist(sinop_probs$file_info[[1]]$path))))
 })
-test_that("Classification with XGBoost", {
 
+test_that("Classification with XGBoost", {
     xgb_model <- sits_train(samples_modis_ndvi, sits_xgboost())
 
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
@@ -134,7 +140,6 @@ test_that("Classification with XGBoost", {
 })
 
 test_that("Classification with SVM and Whittaker filter", {
-
     samples_filt <- sits_filter(samples_modis_ndvi, filter = sits_whittaker())
 
     svm_model <- sits_train(samples_filt, sits_svm())
@@ -173,7 +178,6 @@ test_that("Classification with SVM and Whittaker filter", {
 })
 
 test_that("Classification with RFOR and Savitzky-Golay filter", {
-
     samples_filt <- sits_apply(samples_modis_ndvi, NDVI = sits_sgolay(NDVI))
 
     rfor_model <- sits_train(samples_filt, sits_rfor())
@@ -189,14 +193,19 @@ test_that("Classification with RFOR and Savitzky-Golay filter", {
     if (!dir.exists(output_dir)) {
         dir.create(output_dir)
     }
+    start_date <- sits_timeline(sinop)[1]
+    end_date <- sits_timeline(sinop)[length(sits_timeline(sinop))]
     sinop_2014_probs <- sits_classify(
         data = sinop,
         ml_model = rfor_model,
         filter_fn = sits_sgolay(),
+        start_date = start_date,
+        end_date = end_date,
         output_dir = output_dir,
         memsize = 4,
         multicores = 2,
-        progress = FALSE
+        progress = TRUE,
+        verbose = TRUE
     )
 
     expect_true(all(file.exists(unlist(sinop_2014_probs$file_info[[1]]$path))))
@@ -215,7 +224,6 @@ test_that("Classification with RFOR and Savitzky-Golay filter", {
 })
 
 test_that("Classification with MLP", {
-
     torch_model <- sits_train(samples_modis_ndvi, sits_mlp(epochs = 20))
 
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
@@ -254,7 +262,6 @@ test_that("Classification with MLP", {
 })
 
 test_that("Classification with TempCNN", {
-
     torch_model <- sits_train(samples_modis_ndvi, sits_tempcnn(epochs = 20))
 
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
@@ -293,7 +300,6 @@ test_that("Classification with TempCNN", {
 })
 
 test_that("Classification with ResNet", {
-
     torch_model <- sits_train(samples_modis_ndvi, sits_resnet(epochs = 20))
 
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
@@ -331,7 +337,6 @@ test_that("Classification with ResNet", {
 })
 
 test_that("Classification with TAE", {
-
     torch_model <- sits_train(samples_modis_ndvi, sits_tae(epochs = 20))
 
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
@@ -345,7 +350,7 @@ test_that("Classification with TAE", {
     if (!dir.exists(output_dir)) {
         dir.create(output_dir)
     }
-    sinop_2014_probs <-  sits_classify(
+    sinop_2014_probs <- sits_classify(
         data = sinop,
         ml_model = torch_model,
         output_dir = output_dir,
@@ -369,7 +374,6 @@ test_that("Classification with TAE", {
 })
 
 test_that("Classification with LightTAE", {
-
     torch_model <- sits_train(samples_modis_ndvi, sits_lighttae(epochs = 20))
 
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
@@ -408,9 +412,9 @@ test_that("Classification with LightTAE", {
 })
 
 test_that("Classification with cloud band", {
-
     csv_file <- system.file("extdata/samples/samples_sinop_crop.csv",
-                            package = "sits")
+        package = "sits"
+    )
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     cube <- sits_cube(
         source = "BDC",
@@ -474,7 +478,6 @@ test_that("Classification with cloud band", {
 })
 
 test_that("Classification with post-processing", {
-
     rfor_model <- sits_train(samples_modis_ndvi, sits_rfor())
 
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
@@ -507,19 +510,21 @@ test_that("Classification with post-processing", {
     # testing resume feature
     out <- capture_messages({
         expect_message(
-        object = {sits_label_classification(
-            sinop_probs,
-            output_dir = output_dir,
-            progress = FALSE
-        ) },
-        regexp = "Recovery"
+            object = {
+                sits_label_classification(
+                    sinop_probs,
+                    output_dir = output_dir,
+                    progress = FALSE
+                )
+            },
+            regexp = "Recovery"
         )
     })
     expect_true(grepl("output_dir", out[1]))
 
     expect_true(all(file.exists(unlist(sinop_class$file_info[[1]]$path))))
     expect_true(length(sits_timeline(sinop_class)) ==
-                    length(sits_timeline(sinop_probs)))
+        length(sits_timeline(sinop_probs)))
 
     r_obj <- .raster_open_rast(sinop_class$file_info[[1]]$path[[1]])
     max_lab <- max(.raster_get_values(r_obj))
@@ -537,14 +542,15 @@ test_that("Classification with post-processing", {
     # testing the recovery feature
     out <- capture_messages({
         expect_message(
-        object = {
-            sits_smooth(
-                sinop_probs,
-                output_dir = output_dir,
-                multicores = 2,
-                memsize = 4
-            )},
-        regexp = "Recovery"
+            object = {
+                sits_smooth(
+                    sinop_probs,
+                    output_dir = output_dir,
+                    multicores = 2,
+                    memsize = 4
+                )
+            },
+            regexp = "Recovery"
         )
     })
     expect_true(grepl("output_dir", out[1]))
@@ -552,7 +558,7 @@ test_that("Classification with post-processing", {
     expect_true(all(file.exists(unlist(sinop_bayes$file_info[[1]]$path))))
 
     expect_true(length(sits_timeline(sinop_bayes)) ==
-                    length(sits_timeline(sinop_probs)))
+        length(sits_timeline(sinop_probs)))
 
     r_bay <- .raster_open_rast(sinop_bayes$file_info[[1]]$path[[1]])
     expect_true(.raster_nrows(r_bay) == .tile_nrows(sinop_probs))
@@ -604,9 +610,11 @@ test_that("Classification with post-processing", {
         version = "v1",
         labels = sits_labels(sinop_class),
         data_dir = output_dir,
-        parse_info = c("X1", "X2", "tile",
-                       "start_date", "end_date",
-                       "band", "version"),
+        parse_info = c(
+            "X1", "X2", "tile",
+            "start_date", "end_date",
+            "band", "version"
+        ),
         progress = FALSE
     )
 
@@ -632,7 +640,54 @@ test_that("Classification with post-processing", {
     expect_true(all(file.remove(unlist(sinop_probs$file_info[[1]]$path))))
     expect_true(all(file.remove(unlist(sinop_uncert$file_info[[1]]$path))))
 })
+
 test_that("Raster GDAL datatypes", {
     gdal_type <- .raster_gdal_datatype("INT2U")
     expect_equal(gdal_type, "UInt16")
 })
+
+test_that("Raster terra interface", {
+    r_obj <- .raster_new_rast.terra(
+        nrows = 766,
+        ncols = 1307,
+        xmin = 534780,
+        ymin = 9025580,
+        xmax = 560920,
+        ymax = 9040900,
+        nlayers = 1,
+        crs = 3270
+    )
+    expect_equal(nrow(r_obj), 766)
+    expect_equal(ncol(r_obj), 1307)
+    expect_equal(terra::xmin(r_obj), 534780)
+
+    r_obj_1 <- .raster_new_rast.terra(
+        nrows = 766,
+        ncols = 1307,
+        xmin = 534780,
+        ymin = 9025580,
+        xmax = 560920,
+        ymax = 9040900,
+        nlayers = 1,
+        crs = 3270,
+        xres = 20,
+        yres = 20
+    )
+    expect_equal(nrow(r_obj_1), 766)
+    expect_equal(ncol(r_obj_1), 1307)
+    expect_equal(terra::xmin(r_obj_1), 534780)
+
+    block <- c("col" = 1, "row" = 1, "ncols" = 100, "nrows" = 100)
+    bbox <- .raster_bbox(r_obj, block = block)
+    expect_equal(bbox[["xmin"]], 534780)
+    expect_equal(bbox[["ymin"]], 9038900)
+    expect_equal(bbox[["xmax"]], 536780)
+    expect_equal(bbox[["ymax"]], 9040900)
+
+    prodes_dir <- system.file("extdata/raster/prodes", package = "sits")
+    prodes_file <- list.files(prodes_dir)
+    r_clone <- .raster_clone(paste0(prodes_dir, "/" ,prodes_file), nlayers = 1)
+    r_prodes <- .raster_open_rast(paste0(prodes_dir, "/", prodes_file))
+    expect_equal(nrow(r_clone), nrow(r_prodes))
+    expect_equal(ncol(r_clone), ncol(r_prodes))
+})
